dbos.constants

Constants for DBOS workflow statuses and related status sets.

Pure data (no interop), so this namespace is .cljc and frontend-safe: a ClojureScript UI can share the same status strings/sets as the backend. See: dev.dbos.transact.workflow.WorkflowState

Constants for DBOS workflow statuses and related status sets.

Pure data (no interop), so this namespace is `.cljc` and frontend-safe:
a ClojureScript UI can share the same status strings/sets as the backend.
See: dev.dbos.transact.workflow.WorkflowState
raw docstring

all-statusesclj/s

Set of all possible DBOS workflow statuses.

Set of all possible DBOS workflow statuses.
sourceraw docstring

error-statusesclj/s

Set of statuses indicating workflow failed or was terminated.

Set of statuses indicating workflow failed or was terminated.
sourceraw docstring

in-progress-statusesclj/s

Set of statuses indicating workflow is still running or queued.

Set of statuses indicating workflow is still running or queued.
sourceraw docstring

status-cancelledclj/s

Workflow was cancelled before completion.

Workflow was cancelled before completion.
sourceraw docstring

status-enqueuedclj/s

Workflow has been queued but not yet started execution.

Workflow has been queued but not yet started execution.
sourceraw docstring

status-errorclj/s

Workflow encountered an error during execution.

Workflow encountered an error during execution.
sourceraw docstring

status-max-recovery-attempts-exceededclj/s

Workflow exceeded the maximum number of recovery attempts after errors.

Workflow exceeded the maximum number of recovery attempts after errors.
sourceraw docstring

status-pendingclj/s

Workflow has been started and is currently executing.

Workflow has been started and is currently executing.
sourceraw docstring

status-successclj/s

Workflow completed successfully.

Workflow completed successfully.
sourceraw docstring

terminal-statusesclj/s

Set of statuses indicating workflow has finished (successfully or not).

Set of statuses indicating workflow has finished (successfully or not).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries