Constants for DBOS workflow statuses and related status sets.
Pure data (no interop), so this namespace is .cljc and frontend-safe:
a ClojureScript UI can share the same status strings/sets as the backend.
See: dev.dbos.transact.workflow.WorkflowState
Constants for DBOS workflow statuses and related status sets. Pure data (no interop), so this namespace is `.cljc` and frontend-safe: a ClojureScript UI can share the same status strings/sets as the backend. See: dev.dbos.transact.workflow.WorkflowState
Set of all possible DBOS workflow statuses.
Set of all possible DBOS workflow statuses.
Set of statuses indicating workflow failed or was terminated.
Set of statuses indicating workflow failed or was terminated.
Set of statuses indicating workflow is still running or queued.
Set of statuses indicating workflow is still running or queued.
Workflow was cancelled before completion.
Workflow was cancelled before completion.
Workflow has been queued but not yet started execution.
Workflow has been queued but not yet started execution.
Workflow encountered an error during execution.
Workflow encountered an error during execution.
Workflow exceeded the maximum number of recovery attempts after errors.
Workflow exceeded the maximum number of recovery attempts after errors.
Workflow has been started and is currently executing.
Workflow has been started and is currently executing.
Workflow completed successfully.
Workflow completed successfully.
Set of statuses indicating workflow has finished (successfully or not).
Set of statuses indicating workflow has finished (successfully or not).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |